import React, { Suspense, lazy } from "react";
import { Switch, Route } from "react-router-dom";
import { connect } from 'react-redux';

import * as routes from './constants/routes';

import Header from "./containers/Header";
import landingPage from './components/public-components/landingPage';
import Footer from './components/public-components/footer';
import PrivateRouter from './components/common/privateRouter';
import PrivateAdminRouter from './components/common/privateAdminRouter';

import Spinner from "./components/common/spinner";

const notFound = lazy(() => import("./components/public-components/notFound"));
// const permissionDenied = lazy(() => import("./components/public-components/permissionDenied"));

const homePage = lazy(() => import("./components/user-components/homePage"));
const signInPage = lazy(() => import("./containers/auth/SignInPage"));
const signUpPage = lazy(() => import("./containers/auth/SignUpPage"));
const createTestForm = lazy(() => import("./components/user-components/admin-components/createTestForm"));
const profilePage = lazy(() => import('./components/user-components/profilePage'))

class Router extends React.Component {

    checkUserInLocalStorage = () => {
        // localStorage.getItem(token)
    }

    //chunk.js warnings are disabled !

    componentDidMount() {
    }

    render() {
        const { user } = this.props;

        return (
            <div className="app">
                <Header />
                <Suspense fallback={<Spinner />}>
                    <Switch>
                        <Route path={routes.LANDING} exact component={landingPage} />
                        <Route path={routes.SIGN_UP} exact component={signUpPage} />
                        <Route path={routes.SIGN_IN} exact component={signInPage} />
                        <Route path={routes.HOME} exact component={homePage} />

                        {/* should be protected */}
                        <Route path={routes.CREATE_TEST} exact component={createTestForm} /> 
                        <Route path={routes.PROFILE} user={user} exact component={profilePage} />

                        <PrivateRouter path={routes.HOME} user={user} exact component={homePage} />
                        <PrivateRouter path={routes.TESTS} user={user} exact component={null} />
                        <PrivateRouter path={routes.CATEGORIES} user={user} exact component={null} />

                        <PrivateAdminRouter path={routes.CREATE_CATEGORY} user={user} exact component={null} />
                        <PrivateAdminRouter path={routes.DELETE_USER} user={user} exact component={null} />

                        <Route component={notFound} />
                    </Switch>
                </Suspense>
                <Footer />
            </div>
        )
    }
}

// const
//     mapStateToProps = state => ({
//         user: state.user
//     })

// export default connect()(Router)

export default Router;